---
title: pcg_skel
---

Basic functions for generating chunk-resolution skeletons from a pychunkedgraph.

::: pcg_skel.pcg_skel
    options:
        show_source: false
        heading_level: 2
        members: ['pcg_graph', 'pcg_skeleton', 'pcg_skeleton_direct', 'pcg_meshwork']
